@@ -192,8 +192,11 @@ class CanonicalListing(object):
             self.errors.append((pane, item, self.items[ci][pane]))
 
     def get(self):
-        first = lambda seq: next(s for s in seq if s)
-        filled = lambda seq: tuple([s or first(seq) for s in seq])
+        def first_nonempty(seq):
+            for s in seq:
+                if s:
+                    return s
+        filled = lambda seq: tuple([s or first_nonempty(seq) for s in seq])
         return sorted([filled(v) for v in self.items.itervalues()])
 
 
@@ -715,15 +718,17 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
         if not cursor_path:
             self.emit("next-diff-changed", False, False)
         else:
-            if self.current_path:
+            try:
                 old_cursor = self.model.get_iter(self.current_path)
+            except (ValueError, TypeError):
+                # An invalid path gives ValueError; None gives a TypeError
+                skip = False
+            else:
                 state = self.model.get_state(old_cursor, 0)
                 # We can skip recalculation if the new cursor is between the
                 # previous/next bounds, and we weren't on a changed row
                 skip = state in (tree.STATE_NORMAL, tree.STATE_EMPTY) and \
                        self.prev_path < cursor_path < self.next_path
-            else:
-                skip = False
 
             if not skip:
                 prev, next = self.model._find_next_prev_diff(cursor_path)
@@ -992,6 +997,8 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
         if event.button == 3:
             treeview.grab_focus()
             path = treeview.get_path_at_pos(int(event.x), int(event.y))
+            if path is None:
+                return False
             selection = treeview.get_selection()
             model, rows = selection.get_selected_rows()
 
